====
item
====

.. automodule:: cmkinitramfs.item
   :platform: Linux

.. autoexception:: MergeError
   :show-inheritance:

.. autoclass:: Item
   :members: is_mergeable, merge, build_from_cpio_list,
      build_to_cpio_list, build_to_directory
   :special-members: __iter__, __contains__
   :show-inheritance:

.. autoclass:: File
   :show-inheritance:

.. autoclass:: Directory
   :show-inheritance:

.. autoclass:: Node
   :show-inheritance:

.. autoclass:: Symlink
   :show-inheritance:

.. autoclass:: Pipe
   :show-inheritance:

.. autoclass:: Socket
   :show-inheritance:

